@@ -14,7 +14,7 @@ package clojure.lang;
 
 public abstract class AFn implements IFn {
 
-public Object call() throws Exception{
+public Object call() {
 	return invoke();
 }
 
@@ -25,116 +25,116 @@ public void run(){
 		}
 	catch(Exception e)
 		{
-		throw new RuntimeException(e);
+		throw Util.runtimeException(e);
 		}
 }
 
 
 
-public Object invoke() throws Exception{
+public Object invoke() {
 	return throwArity(0);
 }
 
-public Object invoke(Object arg1) throws Exception{
+public Object invoke(Object arg1) {
 	return throwArity(1);
 }
 
-public Object invoke(Object arg1, Object arg2) throws Exception{
+public Object invoke(Object arg1, Object arg2) {
 	return throwArity(2);
 }
 
-public Object invoke(Object arg1, Object arg2, Object arg3) throws Exception{
+public Object invoke(Object arg1, Object arg2, Object arg3) {
 	return throwArity(3);
 }
 
-public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4) throws Exception{
+public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4) {
 	return throwArity(4);
 }
 
-public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5) throws Exception{
+public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5) {
 	return throwArity(5);
 }
 
-public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6) throws Exception{
+public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6) {
 	return throwArity(6);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7)
-		throws Exception{
+		{
 	return throwArity(7);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
-                     Object arg8) throws Exception{
+                     Object arg8) {
 	return throwArity(8);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
-                     Object arg8, Object arg9) throws Exception{
+                     Object arg8, Object arg9) {
 	return throwArity(9);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
-                     Object arg8, Object arg9, Object arg10) throws Exception{
+                     Object arg8, Object arg9, Object arg10) {
 	return throwArity(10);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
-                     Object arg8, Object arg9, Object arg10, Object arg11) throws Exception{
+                     Object arg8, Object arg9, Object arg10, Object arg11) {
 	return throwArity(11);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
-                     Object arg8, Object arg9, Object arg10, Object arg11, Object arg12) throws Exception{
+                     Object arg8, Object arg9, Object arg10, Object arg11, Object arg12) {
 	return throwArity(12);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13)
-		throws Exception{
+		{
 	return throwArity(13);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14)
-		throws Exception{
+		{
 	return throwArity(14);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
-                     Object arg15) throws Exception{
+                     Object arg15) {
 	return throwArity(15);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
-                     Object arg15, Object arg16) throws Exception{
+                     Object arg15, Object arg16) {
 	return throwArity(16);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
-                     Object arg15, Object arg16, Object arg17) throws Exception{
+                     Object arg15, Object arg16, Object arg17) {
 	return throwArity(17);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
-                     Object arg15, Object arg16, Object arg17, Object arg18) throws Exception{
+                     Object arg15, Object arg16, Object arg17, Object arg18) {
 	return throwArity(18);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
-                     Object arg15, Object arg16, Object arg17, Object arg18, Object arg19) throws Exception{
+                     Object arg15, Object arg16, Object arg17, Object arg18, Object arg19) {
 	return throwArity(19);
 }
 
 public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7,
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
                      Object arg15, Object arg16, Object arg17, Object arg18, Object arg19, Object arg20)
-		throws Exception{
+		{
 	return throwArity(20);
 }
 
@@ -143,15 +143,15 @@ public Object invoke(Object arg1, Object arg2, Object arg3, Object arg4, Object
                      Object arg8, Object arg9, Object arg10, Object arg11, Object arg12, Object arg13, Object arg14,
                      Object arg15, Object arg16, Object arg17, Object arg18, Object arg19, Object arg20,
                      Object... args)
-		throws Exception{
+		{
 	return throwArity(21);
 }
 
-public Object applyTo(ISeq arglist) throws Exception{
+public Object applyTo(ISeq arglist) {
 	return applyToHelper(this, Util.ret1(arglist,arglist = null));
 }
 
-static public Object applyToHelper(IFn ifn, ISeq arglist) throws Exception{
+static public Object applyToHelper(IFn ifn, ISeq arglist) {
 	switch(RT.boundedLength(arglist, 20))
 		{
 		case 0:
@@ -434,7 +434,6 @@ static public Object applyToHelper(IFn ifn, ISeq arglist) throws Exception{
 public Object throwArity(int n){
 	String name = getClass().getSimpleName();
 	int suffix = name.lastIndexOf("__");
-	throw new IllegalArgumentException("Wrong number of args (" + n + ") passed to: "
-	                                   + (suffix == -1 ? name : name.substring(0, suffix)).replace('_', '-'));
+	throw new ArityException(n, (suffix == -1 ? name : name.substring(0, suffix)).replace('_', '-'));
 }
 }
