@@ -13,6 +13,6 @@
 package clojure.lang;
 
 public interface IReference extends IMeta {
-    IPersistentMap alterMeta(IFn alter, ISeq args) throws Exception;
+    IPersistentMap alterMeta(IFn alter, ISeq args) ;
     IPersistentMap resetMeta(IPersistentMap m);
 }
