@@ -9,4 +9,8 @@
       33 (+ 32 (inc (* 32 32))) (+ 32 (inc (* 32 32 32)))))
   (testing "off the end"
     (is (thrown-with-msg? IllegalStateException #"Can't pop empty vector"
-          (-> [] transient pop!)))))
+          (-> [] transient pop!))))
+  (testing "copying array from a non-editable when put in tail position")
+    (is (= 31 (let [pv (vec (range 34))]
+                (-> pv transient pop! pop! pop! (conj! 42))
+                (nth pv 31)))))
